@@ -29,6 +29,7 @@
 
 #include <stdio.h>
 
+#include "radeon_compiler_util.h"
 #include "../r300_reg.h"
 
 /**
@@ -39,10 +40,12 @@ int r500_transform_IF(
 	struct rc_instruction * inst,
 	void* data)
 {
+	struct rc_instruction * inst_mov;
+
 	if (inst->U.I.Opcode != RC_OPCODE_IF)
 		return 0;
 
-	struct rc_instruction * inst_mov = rc_insert_new_instruction(c, inst->Prev);
+	inst_mov = rc_insert_new_instruction(c, inst->Prev);
 	inst_mov->U.I.Opcode = RC_OPCODE_MOV;
 	inst_mov->U.I.DstReg.WriteMask = 0;
 	inst_mov->U.I.WriteALUResult = RC_ALURESULT_W;
@@ -251,12 +254,11 @@ void r500FragmentProgramDump(struct radeon_compiler *c, void *user)
 {
   struct r300_fragment_program_compiler *compiler = (struct r300_fragment_program_compiler*)c;
   struct r500_fragment_program_code *code = &compiler->code->code.r500;
-  fprintf(stderr, "R500 Fragment Program:\n--------\n");
-
   int n, i;
   uint32_t inst;
   uint32_t inst0;
   char *str = NULL;
+  fprintf(stderr, "R500 Fragment Program:\n--------\n");
 
   for (n = 0; n < code->inst_end+1; n++) {
     inst0 = inst = code->inst[n].inst0;
